View source: R/parse_env_subset.R
| parse_env_subset | R Documentation |
Helper function to infer target from expression and environment
parse_env_subset(
expr,
envir = parent.frame(),
substitute = TRUE,
is_variable = TRUE
)
expr |
An expression. |
envir |
An environment. |
substitute |
If |
is_variable |
(logical) If TRUE and an element name is specified, then the name is checked to be a valid variable name. |
A named list with elements:
envirAn environment (defaults to argument envir)
nameA character vector. ...
op...
subsetA list of subsetting indices or NULL. ...
idxAn integer vector or NA_integer_. ...
existsA logical vector of length length(idx) with TRUE
and FALSE values.
codeThe deparsed expression expr coerced to a single character
string.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.